Enum Tampmsk
#[repr(u8)]pub enum Tampmsk {
ResetBySoftware = 0,
ResetByHardware = 1,
}Variants
ResetBySoftware = 0
Tamper x event generates a trigger event and TAMPxF must be cleared by software to allow next tamper event detection
ResetByHardware = 1
Tamper x event generates a trigger event. TAMPxF is masked and internally cleared by hardware. The backup registers are not erased. The tamper x interrupt must not be enabled when TAMP3MSK is set
Implementations